'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var melodyCompiler = require('melody-compiler');
var babel = require('babel-core');
var melodyExtensionCore = require('melody-extension-core');
var idomPlugin = _interopDefault(require('melody-plugin-idom'));
var p = require('process');
var findBabelConfig = _interopDefault(require('find-babel-config'));

/**
 * Copyright 2017 trivago N.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS-IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

function getBabelConf() {
    var _findBabelConfig$sync = findBabelConfig.sync(p.cwd()),
        config = _findBabelConfig$sync.config;

    if (!config) {
        throw new Error('Couldn\'t find .babelrc or babel entry on package.json! You can specify custom config with "transformer". Please consult documentation.');
    }
    return config;
}

function process(src, path) {
    transformer(src, path);
}

function transformer(src, path) {
    var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

    var plugins = options.plugins || [melodyExtensionCore.extension, idomPlugin];
    var babelConfig = options.babel || getBabelConf();

    var compiledMelody = melodyCompiler.toString(melodyCompiler.compile.apply(undefined, [path, src].concat(plugins)), src).code;
    if (options.noBabel) {
        return compiledMelody;
    }

    return babel.transform(compiledMelody, babelConfig).code;
}

/**
 * Copyright 2017 trivago N.V.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS-IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

exports.process = process;
exports.transformer = transformer;
